┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/urlnavigator.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/urlnavigator.h')
-rw-r--r--src/urlnavigator.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/urlnavigator.h b/src/urlnavigator.h
index 6a3d7d579..4b571b98d 100644
--- a/src/urlnavigator.h
+++ b/src/urlnavigator.h
@@ -243,11 +243,11 @@ private slots:
void slotRedirection(const KUrl&, const KUrl&);
/**
* Switches the navigation bar between the editable and noneditable
* state (see setUrlEditable()) and is connected to the clicked signal
* of the navigation bar button.
*/
- void slotClicked();
+ void switchView();
private:
/**
@@ -301,6 +301,7 @@ private:
QLabel* m_protocolSeparator;
QLineEdit* m_host;
QLinkedList<UrlNavigatorButton*> m_navButtons;
+ QWidget* m_filler;
//UrlStack m_urls;
};
@@ -243,11 +243,11 @@ private slots:
void slotRedirection(const KUrl&, const KUrl&);
/**
- * Switches the navigation bar between the editable and noneditable
- * state (see setUrlEditable()) and is connected to the clicked signal
+ * Switches the navigation bar between the breadcrumb view and the
+ * traditional view (see setUrlEditable()) and is connected to the clicked signal
* of the navigation bar button.
*/